@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/filewin.c,v 1.15 1998/05/10 20:02:24 werner Rel $
+ * $Header: /home/werner/ytree/RCS/filewin.c,v 1.16 1998/11/11 19:02:48 werner Rel $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -470,7 +470,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   char format[60];
   char justify;
   char *line_ptr;
-  int  n, pos_x;
+  int  n, pos_x = 0;
   FileEntry *fe_ptr;
   static char *line_buffer = NULL;
   static int  old_cols = -1;
@@ -518,7 +518,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
-		      (void) sprintf( format, "%%c %%+%ds %%10s %%3d %%7d %%12s -> %%-%ds", 
+		      (void) sprintf( format, "%%c%%+%ds %%10s %%3d %%7d %%12s -> %%-%ds", 
 				      max_filename_len,
 				      max_linkname_len
 				    );
@@ -535,7 +535,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                     }
 		    else
 		    {
-		      (void) sprintf( format, "%%c %%%c%ds %%10s %%3d %%7d %%12s", 
+		      (void) sprintf( format, "%%c%%%c%ds %%10s %%3d %%7d %%12s", 
                                       justify,
 				      max_filename_len 
 				    );
@@ -587,7 +587,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
-                      (void) sprintf( format, "%%c %%%c%ds %%10s %%5d  %%-8s  %%-8s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s -> %%-%ds",
                                       justify,
 			              max_filename_len,
 			              max_linkname_len
@@ -604,7 +604,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                     }
 		    else
 		    {
-                      (void) sprintf( format, "%%c %%%c%ds %%10s %%5d  %%-8s  %%-8s",
+                      (void) sprintf( format, "%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s",
                                       justify,
 			              max_filename_len
 				      );
@@ -635,7 +635,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
     
     case MODE_3 : if( fe_ptr )
 		  {
-		    (void) sprintf( format, "%%c %%%c%ds", 
+		    (void) sprintf( format, "%%c%%%c%ds", 
                                     justify, 
                                     max_filename_len );
 
@@ -663,7 +663,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
-                      (void) sprintf( format, "%%c %%%c%ds Chg.: %%12s  Acc.: %%12s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%%c%ds Chg: %%12s  Acc: %%12s -> %%-%ds",
                                       justify,
 				      max_filename_len,
 				      max_linkname_len
@@ -678,7 +678,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                     }
 		    else
 		    {
-                      (void) sprintf( format, "%%c %%%c%ds Chg.: %%12s  Acc.: %%12s",
+                      (void) sprintf( format, "%%c%%%c%ds Chg: %%12s  Acc: %%12s",
                                       justify,
 				      max_filename_len
 				    );
@@ -788,7 +788,7 @@ static void DisplayFiles(DirEntry *de_ptr, int start_file_no, int hilight_no, in
 	      );
   }
 
-  j = start_file_no; p_x = -1;
+  j = start_file_no; p_x = -1; p_y = 0;
   for( x=0; x < max_column; x++)
   {
     for( y=0; y < window_height; y++ )
@@ -1154,7 +1154,7 @@ int HandleFileWindow(DirEntry *dir_entry,
 {
   FileEntry *fe_ptr;
   FileEntry *new_fe_ptr;
-  DirEntry  *de_ptr;
+  DirEntry  *de_ptr = NULL;
   DirEntry  *dest_dir_entry;
   WalkingPackage walking_package;
   int ch;
@@ -1993,6 +1993,15 @@ int HandleFileWindow(DirEntry *dir_entry,
 		        
 			if( file_count == 0 ) unput_char = ESC;
 
+			if( start_file + cursor_pos >= file_count )
+			{
+			  if( --cursor_pos < 0 )
+			  {
+			    start_file--;
+			    cursor_pos = 0;
+			  }
+			}
+  
 			DisplayFiles( dir_entry, 
 				      start_file, 
 				      start_file + cursor_pos,
