@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/login.c,v 1.14 1998/05/10 20:02:24 werner Rel $
+ * $Header: /home/werner/ytree/RCS/login.c,v 1.15 1998/11/11 19:02:48 werner Rel $
  *
  * Dateibaum lesen
  *
@@ -49,10 +49,10 @@ int LoginDisk(char *path)
   struct stat stat_struct;
   char   command_line[COMMAND_LINE_LENGTH + 1];
   char   cat_file_name[PATH_LENGTH+1];
-  int    file_method;
+  int    file_method = 0;
   int    pid;
   int    p[2];
-  int    l, depth;
+  int    depth, l = 0;
   FILE   *f;
   int    status;
   int    result = 0;
