@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/match.c,v 1.10 1997/08/13 12:24:58 werner Rel $
+ * $Header: /home/werner/ytree/RCS/match.c,v 1.11 1998/11/11 19:02:48 werner Rel $
  *
  * Behandlung reg. Ausdruecke fuer Dateinamen
  *
@@ -9,7 +9,7 @@
 
 #include "ytree.h"
 
-#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 )
+#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ )
 #define HAS_REGEX
 #endif
 
@@ -117,7 +117,8 @@ int SetMatchSpec(char *new_spec)
 
 #else
 
-#ifndef WIN32
+#if (!(defined(WIN32) || defined(__DJGPP__)))
+
 
   if( ( result = regcmp( buffer, (char *) 0 ) ) == NULL )
   {
@@ -172,7 +173,8 @@ BOOL Match(char *file_name)
 
 #else
 
-#ifndef WIN32
+#if (!(defined(WIN32) || defined(__DJGPP__)))
+
 
   char match_part[PATH_LENGTH + 1];
 
