@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/quit.c,v 1.10 1997/08/13 12:24:58 werner Rel $
+ * $Header: /home/werner/ytree/RCS/quit.c,v 1.11 1998/11/11 19:02:48 werner Rel $
  *
  * Verlassen von ytree
  *
@@ -20,9 +20,9 @@ void Quit(void)
   char path[PATH_LENGTH + 1];
   char *p;
 
-  term = InputChoise( "quit ytree (Y/N) ?", "YN\r\033" );
+  term = InputChoise( "quit ytree (Y/N) ?", "YNQq\r\033" );
 
-  if( term == 'Y' )
+  if( term == 'Y' || term == 'Q' || term == 'q' )
   {
     if (( p = getenv("HOME") ))
     {
