@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/util.c,v 1.15 1998/07/26 21:21:13 werner Rel $
+ * $Header: /home/werner/ytree/RCS/util.c,v 1.16 1998/11/11 19:02:48 werner Rel $
  *
  * Diverse Hilfsfunktionen
  *
@@ -205,7 +205,7 @@ int GetFileEntry(DirEntry *de_ptr, char *file_name, FileEntry **file_entry)
 
 
 
-char *GetAttributes(ushort modus, char *buffer)
+char *GetAttributes(unsigned short modus, char *buffer)
 {
   char *save_buffer = buffer;
 
@@ -689,6 +689,7 @@ char *FormFilename(char *dest, char *src, unsigned int max_len)
   unsigned int l;
 
   l = strlen(src);
+  begin = 0;
 
   if( l <= max_len )
     return( strcpy( dest, src ) );
