@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /home/werner/ytree/RCS/ytree.h,v 1.18 1998/07/26 21:21:13 werner Rel $
+ * $Header: /home/werner/ytree/RCS/ytree.h,v 1.19 1998/11/11 19:02:48 werner Rel $
  *
  * Header-Datei fuer YTREE
  *
@@ -19,7 +19,11 @@
 #ifdef ultrix
 #include <cursesX.h>
 #else
+#ifdef __FreeBSD__
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif /* __FreeBSD__ */
 #endif /* ultrix */
 
 #include <limits.h>
@@ -27,6 +31,7 @@
 #include <sys/stat.h>
 #include <time.h>
 #ifdef linux
+#include <sys/wait.h>
 #include <sys/time.h>	/* needed vor RedHed5 (thanks to Robert Spier) */
 #endif
 
@@ -145,6 +150,21 @@ extern char *getcwd();
 #endif /* WIN32 */
 
 
+
+#ifdef __DJGPP__
+
+/* DJGPP GNU DOS Compiler                           */
+/*--------------------------------------------------*/
+
+#define  putp( str )                 puts( str )
+#define  vidattr( attr )
+#define  typeahead( file )
+
+#endif /* __DJGPP__*/
+
+
+
+
 #ifdef TERMCAP
 
 #define  KEY_BTAB         5000
@@ -449,8 +469,10 @@ extern char *getcwd();
 			   { ".LZH", LHA_COMPRESS },                 \
 			   { ".arc", ARC_COMPRESS },                 \
 			   { ".ARC", ARC_COMPRESS },                 \
+			   { ".jar", ZIP_COMPRESS },                 \
 			   { ".zip", ZIP_COMPRESS },                 \
 			   { ".ZIP", ZIP_COMPRESS },                 \
+			   { ".JAR", ZIP_COMPRESS },                 \
 			   { ".rpm", RPM_COMPRESS },                 \
 			   { ".RPM", RPM_COMPRESS }                  \
 			 }
@@ -787,7 +809,7 @@ extern int  HandleFileWindow(DirEntry *dir_entry,
 			     int cursor_pos,
 			     BOOL global_flag,
 			     BOOL big_window);
-extern char *GetAttributes(ushort modus, char *buffer);
+extern char *GetAttributes(unsigned short modus, char *buffer);
 extern void SwitchToSmallFileWindow(void);
 extern void SwitchToBigFileWindow(void);
 extern int  ReadGroupEntries(void);
